@@ -8,7 +8,7 @@ from kdp_connector.connectors.query import QueryApi
 from kdp_connector.connectors.index_management import IndexManagementApi
 from kdp_connector.connectors.upload import UploadApi
 from kdp_api.models import SecurityLabelInfoParams
-
+from pandas import DataFrame
 
 class KdpConn(object):
     """This class contains convenience methods used for interacting with KDP"""
@@ -92,7 +92,14 @@ class KdpConn(object):
 
 
     # WRITE
-    def batch_write_v2(self, dataframe, dataset_id: str, jwt: str, security_label_info_params: SecurityLabelInfoParams = None, batch_size: int = 100, is_async: bool = True):
+    def batch_write_v2(self,
+            dataframe: DataFrame,
+            dataset_id: str,
+            jwt: str,
+            security_label_info_params: SecurityLabelInfoParams = None,
+            batch_size: int = 100,
+            is_async: bool = True,
+            is_compressed: bool = False):
         """This method will be used to write batches of data to KDP
 
             :param DataFrame dataframe: Data to write to KDP
@@ -100,21 +107,23 @@ class KdpConn(object):
             :param str jwt: JWT token
             :param SecurityLabelInfoParams security_label_info_params: Security Label Parser Parameter configuration
             :param int batch_size: Defaults to 100
-            :param bool is_async: Defaults to True
+            :param bool is_async: Is the request async. Defaults to True
+            :param bool is_compressed: If true, gzip-compress the request payload. Defaults to False
 
             :returns: Set of partitions data was written to
 
             :rtype: set
         """
-        write_api = WriteApi()
         config = self.create_configuration(jwt)
+        write_api = WriteApi(config)
         return write_api.batch_write_v2(
             config=config,
             dataset_id=dataset_id,
             dataframe=dataframe,
             security_label_info_params=security_label_info_params,
             batch_size=batch_size,
-            is_async=is_async)
+            is_async=is_async,
+            is_compressed=is_compressed)
 
 
 
